@@ -17,12 +17,12 @@
 # 02110-1301, USA.
 #
 import json
+import httplib
 import socket
 import string
 import sys
 import time
 
-from oas import oas_httplib
 from oas.oas_util import get_assign, append_param
 
 
@@ -40,20 +40,11 @@ class OASAPI(object):
         self.secret_access_key = accessKey
 
     def __get_connection(self):
-        timeout = 100
-        host = self.host
-        port = self.port
-        if self.is_security or port == 443:
+        if self.is_security or self.port == 443:
             self.is_security = True
-            if sys.version_info >= (2, 6):
-                return oas_httplib.HTTPSConnection(host=host, port=port, timeout=timeout)
-            else:
-                return oas_httplib.HTTPSConnection(host=host, port=port)
+            return httplib.HTTPSConnection(host=self.host, port=self.port)
         else:
-            if sys.version_info >= (2, 6):
-                return oas_httplib.HTTPConnection(host=host, port=port, timeout=timeout)
-            else:
-                return oas_httplib.HTTPConnection(host=host, port=port)
+            return httplib.HTTPConnection(host=self.host, port=self.port)
 
     def __get_resource(self, params=None):
         if not params:
@@ -151,7 +142,7 @@ class OASAPI(object):
             if string.find(error_info, bpipe_error) >= 0:
                 return conn.getresponse()
             else:
-                raise Exception('Request error! ' + e.message)
+                raise Exception('Request error! ' + str(e))
 
     def __create_sign_for_normal_auth(self, method, headers=None, resource='/'):
         '''
